# [[ Header ]]

# Copyright (c) 1996 by SoftWorks.  All Rights Reserved.
# File:   tests.tcl
# Author: Richard Schwaninger
# Date:   20/02/1996
# System: chiron.standalone
# RCS:    $Id: tests.tcl,v 1.2 1996/04/17 07:33:15 risc Exp $

# [endfold]

set simplewish 0

if { ![info exists AppName] } {
   set simplewish 1
} 

if {$simplewish} {
   source font.tcl
   proc Test { a b c d } {
      puts "Test $a:$b"
      if { [catch {
	 eval $c
      } err]!=0 } {
	 puts "Error in $a:$b: $err"
	 return
      }
      if { [string compare $err $d]!=1 } {
	 puts "bad result in $a:$b: '$err'\nshould be '$d'"
	 return
      }
      puts "ok"
   }
} else {
   Require tclkit 3
   TestLoad font
   Require tk 4.1
}	 


font_Init

# XLFD
# registry
# foundry
# family
# weight
# slant
# setwidth
# style
# pixel
# size
# xres
# yres
# spacing
# width
# charset
# encoding

# [[ simple font tests ]]

Test f1 "simple default" {
   Font get
} *-*-*-*-*-*-*-*-*-*-*-*-*-*-*

Test f2 "simple default default" {
   Font get Default
} *-*-*-*-*-*-*-*-*-*-*-*-*-*-*

Test f3 "simple default change" {

   Font get Default -size 14
} *-*-*-*-*-*-*-*-140-*-*-*-*-*-*

Test f4 "simple default change2" {
   Font get Default -encoding 8 -foundry adobe
} *-adobe-*-*-*-*-*-*-*-*-*-*-*-*-8

Test f5 "full spec" {
   Font get Default \
	-weight dark \
	-slant x \
	-width default \
	-style sans \
	-pixel 14 \
	-size 14 \
	-xres 100 \
	-yres 120 \
	-spacing p \
	-avgwidth 160 \
	-charset bah \
   	-encoding 8
} *-*-*-dark-x-default-sans-14-140-100-120-p-160-bah-8

# [endfold]
# [[ font definitions ]]

Test d1 "define font empty" {
   Font def d1 
   Font get d1
} *-*-*-*-*-*-*-*-*-*-*-*-*-*-*
Test d2 "define font" {
#cmdtrace on
   Font def d2 {-foundry adobe -family times -charset iso8859} 
   Font get d2
	 
} *-adobe-times-*-*-*-*-*-*-*-*-*-*-iso8859-*
Test d3 "define font with properties" {
   Font def d3 \
	 {-foundry adobe -family helvetica -charset iso8859}
   Font get d3 -slant italic -size 18
} *-adobe-helvetica-*-o-*-*-*-180-*-*-*-*-iso8859-*
Test d4 "define font with defaults" {
   Font def d3 \
	 {-registry {} -foundry adobe -family helvetica -charset iso8859} \
	 {-slant r -width normal -pixel 0 -style *}
#cmdtrace on
   Font get d3 -slant italic -size 16
} *-adobe-helvetica-*-o-normal-*-0-160-*-*-*-*-iso8859-*

Test d5 "define terminal font" {
   Font def d5 \
	 {-registry {} -foundry misc -family fixed -charset iso8859 \
	 -spacing c -pixel 0 -encoding 1 -width normal}
   Font get d5 -size 15 -weight normal -slant normal
} *-misc-fixed-medium-r-normal-*-0-150-*-*-c-*-iso8859-1

# [endfold]
# [[ font setting ]]

Test s1 "set font" {
   Font def s1 \
	 {-foundry adobe -family times -charset iso8859}
   Font set s1 -encoding 1
   Font get s1
} *-adobe-times-*-*-*-*-*-*-*-*-*-*-iso8859-1

Test s2 "set font, empty" {
   Font def s2 \
	 {-foundry adobe -charset iso8859}
   Font set s2
   Font get s2
} *-adobe-*-*-*-*-*-*-*-*-*-*-*-iso8859-*

# [endfold]
# [[ font info ]]

Test i1 "font info" {
   Font def i1 {} \
	 {-slant italic -size 16}
   Font info i1
} "-size 16 -slant italic"

Test i2 "font info default" {
   Font info
} {}
Test i3 "what fonts font" {
   Font def i3 {}  \
	 {-slant italic -size 16}
   Font set i3 -slant normal -width wide
   Font info i3
} "-size 16 -width wide -slant normal"
Test i4 "nonexisting font" {
   Font info i4
} {}
Test i5 "only default font" {
   Font names Default
} Default
Test i6 "font names" {
   set r [Font names *]
   if {([lsearch -exact $r Default]> 0)&&([llength $r]>1)} {
      return 1
   }
   return 0
} 1

# [endfold]
# [[ font existence ]]

Test e1 "exists not" {
   Font exists e1
} 0
Test e2 "exists yes" {
   Font def e2 {-foundry adobe} {}
   Font exists e2
} 1
Test e3 "exists default" {
   Font exists
} 1
Test e4 "exists default" {
   Font exists Default
} 1

# [endfold]
# [[ font errors ]]

Test u1 "usage " {
   try {
      Font 
   } {
      return $err
   }
} {no value given for parameter "cmd" to "Font"}
Test u2 "usage 1" {
   try {
      Font bingo
   } {
      return $err
   }
} "Font <cmd> <args>"

Test u2 "usage 3" {
   try {
      Font bingo krawumm
   } {
      return $err
   }
} "Font <cmd> <args>"
Test u3 "unknown font" {
   try {
      Font get bingo
   } {
      return $err
   }
} "Font 'bingo' does not exist"
Test u4 "unknown font set" {
   try {
      Font set bingo
   } {
      return $err
   }
} "Font 'bingo' does not exist"

# [endfold]
# [[ font defaults ]]

Test x1 "use set defaults" {
   Font def x1
   Font set x1 -slant italic -size 20
   Font get x1
} *-*-*-*-i-*-*-*-200-*-*-*-*-*-*

Test x2 "use set defaults helvetica" {
   Font def x2 {-family helvetica -foundry adobe} {}
   Font set x2  -slant italic -size 20
   Font get x2
} *-adobe-helvetica-*-o-*-*-*-200-*-*-*-*-*-*

# [endfold]
# [[ font copy ]]

Test c1 "copy font" {
   Font def c1-0 {-foundry adobe -family helvetica} \
	 { -slant.italic o } \
	 {-size 10}
   Font copy c1-0 c1-1 -size 20 -width normal
   Font get c1-1 -slant italic
} *-adobe-helvetica-*-o-normal-*-*-200-*-*-*-*-*-*
Test c2 "copy nonexisting source" {
   try {
      Font copy c2-0 c2-1
   } {
      return $err
   }
} "Source font 'c2-0' does not exist"
Test c3 "copy font, exsisting dest" {
   Font def c3-0 {-foundry adobe} \
	 { -slant.italic o } \
	 {size 10}
   Font def c3-1 {-foundry adobe} \
	 { -slant.italic o } \
	 {-size 10}
   try {
      Font copy c3-0 c3-1 -size 20 -width normal
   } {
      return $err
   }
} "Destination font 'c3-0' does exist"

# [endfold]
# [[ separation ]]

Test sa1 "separate font defs" {
   Font def gargl {-foundry adobe -family helvetica}
   Font def urgl {-foundry misc -family fixed}
   Font get gargl
} *-adobe-helvetica-*-*-*-*-*-*-*-*-*-*-*-*

# [endfold]

# EOF